~/talk

Dagger Reflect - The circle from runtime to compile time and back to runtime

Talkat droidCon Berlin 2019 · 2019-07-01..07-03· [android]
slides:none on file

Dagger Reflect replaces Dagger’s heavy generated code with a reflection runtime that cuts annotation‑processing time and speeds local builds: measured average builds drop from 58s to 45s — saves 23% on builds — while the reflect compiler runs in about 60 ms compiler run. A small Gradle plugin called Delect Gradle plugin automates swapping dagger dependencies; artifacts are on Maven Central (dagger‑reflect 0.10, Delect 0.1.0). Some Dagger features and error messages differ and app startup can be slower due to reflection.

AI-written summary · about

  1. 0:00Introduction
  2. 1:58History of DI frameworks
  3. 4:07Problem with Dagger builds
  4. 4:27What is Dagger Reflect
  5. 6:11How reflection works
  6. 10:30Developing Dagger Reflect
  7. 15:12Using Dagger Reflect
  8. 18:27Delect Gradle plugin
  9. 20:14Build speed improvements
  10. 22:20Current state and future
  11. 24:29Usage at SoundCloud
  12. 25:54Build time tracking
  13. 27:40Impact on local builds
  14. 28:00Closing and thanks
~/search
type to search 6,249 conferences, 138,987 speakers and 185,172 talks
~/help
cmdctrl k
search every conference, speaker and series
/
focus the filter search
h
home
c
conferences
s
speakers
e
series
t
light / dark — the status bar button does the same
?
this help
esc
close this, then clear every filter — or just the search, while you are typing in it

Ignored while you are typing. Pages without a filter rail have no search to focus.